LambdaConnExt

Trait LambdaConnExt 

pub trait LambdaConnExt {
    // Required method
    fn lambda_context(&self) -> &Context;
}
Provides access to the aws lambda context for trillium::Conn.

See lamedh_runtime::Context for more details on the data available on this struct.

Required Methods

fn lambda_context(&self) -> &Context

returns the lamedh_runtime::Context for this conn

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl LambdaConnExt for Conn

Implementors